==> MSQC_1.0.0.tar.gz: MSQC/man/larg.ellip.Rd <==
\name{larg.ellip}
\alias{larg.ellip}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Largest ellipsoid
}
\description{
It builds the largest ellipsoid centered at the Target. It uses the g
}
\usage{
larg.ellip(LSL, USL, n = 25, box = FALSE, add = TRUE, xlim = xlim, ylim = ylim, zlim = zlim, xlab = "xlab", ylab = "ylab", zlab = "zlab", col = 2, alpha = 0.2, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{LSL}{
is the lower specification limit
}
  \item{USL}{
is the upper specification limit
}
  \item{n}{
%%     ~~Describe \code{n} here~~
}
  \item{box}{
%%     ~~Describe \code{box} here~~
}
  \item{add}{
%%     ~~Describe \code{add} here~~
}
  \item{xlim}{
%%     ~~Describe \code{xlim} here~~
}
  \item{ylim}{
%%     ~~Describe \code{ylim} here~~
}
  \item{zlim}{
%%     ~~Describe \code{zlim} here~~
}
  \item{xlab}{
%%     ~~Describe \code{xlab} here~~
}
  \item{ylab}{
%%     ~~Describe \code{ylab} here~~
}
  \item{zlab}{
%%     ~~Describe \code{zlab} here~~
}
  \item{col}{
%%     ~~Describe \code{col} here~~
}
  \item{alpha}{
%%     ~~Describe \code{alpha} here~~
}
  \item{\dots}{
%%     ~~Describe \code{\dots} here~~
}
}


\author{
This fucntion is a little modification of a function of the rgl package by Duncan Murdoch 
}


%% ~Make other sections like Warning with \section{Warning }{....} ~


\examples{
#
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line

==> MSQC_1.0.1.tar.gz: MSQC/man/larg.ellip.Rd <==
\name{larg.ellip}
\alias{larg.ellip}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Largest ellipsoid
}
\description{
It builds the largest ellipsoid centered at the Target. It uses the g
}
\usage{
larg.ellip(LSL,USL,n=25,box=FALSE,add=TRUE,xlim=xlim,ylim=ylim,zlim=zlim,
xlab="xlab",ylab="ylab",zlab="zlab",col=2,alpha=0.2,...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{LSL}{
is the lower specification limit
}
  \item{USL}{
is the upper specification limit
}
  \item{n}{
%%     ~~Describe \code{n} here~~
}
  \item{box}{
%%     ~~Describe \code{box} here~~
}
  \item{add}{
%%     ~~Describe \code{add} here~~
}
  \item{xlim}{
%%     ~~Describe \code{xlim} here~~
}
  \item{ylim}{
%%     ~~Describe \code{ylim} here~~
}
  \item{zlim}{
%%     ~~Describe \code{zlim} here~~
}
  \item{xlab}{
%%     ~~Describe \code{xlab} here~~
}
  \item{ylab}{
%%     ~~Describe \code{ylab} here~~
}
  \item{zlab}{
%%     ~~Describe \code{zlab} here~~
}
  \item{col}{
%%     ~~Describe \code{col} here~~
}
  \item{alpha}{
%%     ~~Describe \code{alpha} here~~
}
  \item{\dots}{
%%     ~~Describe \code{\dots} here~~
}
}


\author{
This fucntion is a little modification of a function of the rgl package by Duncan Murdoch 
}


%% ~Make other sections like Warning with \section{Warning }{....} ~


\examples{
#
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
